==> haskell-resource-pool-0.2.3.2-328-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-DA5kYjHl1wI8lgC6PlkaSj
key:                  resource-pool-0.2.3.2-DA5kYjHl1wI8lgC6PlkaSj
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  04b2a3a636fde6d90e7dabcd0237c6f4
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-DA5kYjHl1wI8lgC6PlkaSj
depends:
    base-4.17.2.1 hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    monad-control-1.0.3.1-Gw3XM64JSJ5ntrqlz8Emw stm-2.5.1.0 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-7U7lXEgv0cHELUGOzmogrd
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-329-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 resource-pool
version:              0.2.3.2
visibility:           public
id:                   resource-pool-0.2.3.2-H5U1I0DuM1CCOytzzp3F55
key:                  resource-pool-0.2.3.2-H5U1I0DuM1CCOytzzp3F55
license:              BSD-3-Clause
copyright:            Copyright 2011 MailRank, Inc.
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>,
    Bas van Dijk <v.dijk.bas@gmail.com>

author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://github.com/bos/pool
synopsis:             A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.

category:             Data, Database, Network
abi:                  cef6c40920941ab36dda799ee688fdbd
exposed:              True
exposed-modules:      Data.Pool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-resource-pool
hs-libraries:         HSresource-pool-0.2.3.2-H5U1I0DuM1CCOytzzp3F55
depends:
    base-4.17.2.1 hashable-1.4.4.0-7zzKXDBa1HP1F6vPi1Tvtg
    monad-control-1.0.3.1-98Fvu0ksaxCoCBe6a0Ulj stm-2.5.1.0 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-Jq2Xml4oXw823FCOshquww
    vector-0.13.2.0-F8322NeNtfL69paM3N9AVt

haddock-interfaces:
    /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock

haddock-html:         /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
